@@ -49,6 +49,7 @@ class ModelInfoBase(object):
 
     def get_field_display_value(self, f_name, instance):
         field = self.get_field(f_name)
+        f_value = None
 
         try:
             return getattr(self, 'get_%s_value'%f_name)(instance)
@@ -71,7 +72,7 @@ class ModelInfoBase(object):
         
         if isinstance(f_value, models.Model):
             if self._meta.auto_urlize and hasattr(f_value, 'get_absolute_url') and not f_name in self._meta.list_display_links:
-                return '<a href="%s">%s</a>'%(f_value.get_absolute_url(), f_value)
+                return '<a href="%s">%s</a>'%(f_value.get_absolute_url(), unicode(f_value))
             else:
                 return unicode(f_value)
 
@@ -290,7 +291,13 @@ class ModelList(ModelInfoBase):
             qs = self.queryset.all()
 
             if self._meta.groups:
-                qs = qs.order_by(*self._meta.groups)
+                try:
+                    qs = qs.order_by(*self._meta.groups)
+                except AssertionError, e:
+                    # Ignores the error if it doesn't get to order
+                    if e.message != 'Cannot reorder a query once a slice has been taken.':
+                        raise
+
         except AttributeError:
             qs = self.queryset
 
